@@ -7,6 +7,13 @@ ERROR_LOG_DIR = "errors"
 
 
 def log_exception(show_dialog: bool = True) -> str:
+    """
+    In the event of an exception, this method writes the stacktrace
+    out to a file in the "errors" directory (created if not exists)
+    And shows a dialog alerting the user of the error (if enabled)
+    :param show_dialog: If the dialog box should be shown, informing the user of the error
+    :return: the path to the error log file.
+    """
     if not os.path.isdir(ERROR_LOG_DIR):
         os.makedirs(ERROR_LOG_DIR)
 
