@@ -43,6 +43,23 @@ class GameObject(abc.ABC):
 
         self.hitbox = hitbox.BoundHitbox(self)
 
+        self.visible = True
+
+    def show(self):
+        self.visible = True
+        self.on_visibility_change(self.visible)
+
+    def hide(self):
+        self.visible = False
+        self.on_visibility_change(self.visible)
+
+    def set_visibility(self, visible: bool):
+        self.visible = visible
+        self.on_visibility_change(self.visible)
+
+    def on_visibility_change(self, state: bool):
+        pass
+
     def on_message_receive(self, message: typing.Union[list, tuple, str], sender):
         """
         This event is run when another object on the same screen broadcasts a message
@@ -134,6 +151,14 @@ class GameObject(abc.ABC):
 
             self.check_collision()
 
+    def move(self, dx: float, dy: float):
+        """
+        This moves the object by a factor of dx/dy and triggers the on_move event
+        """
+        self.x += dx
+        self.y += dy
+        self.on_move(dx, dy)
+
     def check_collision(self):
         """
         Causes this object to check for collisions with other objects
