@@ -70,4 +70,4 @@ class Character(game_object.GameObject):
         """
         Draws the character to the specified buffer
         """
-        buffer.blit(self.rendered_text, (self.x, self.y))
+        buffer.blit(self.rendered_text, self.convert_coords(self.x, self.y))
