@@ -91,4 +91,4 @@ class CharacterButton(game_object.GameObject):
         """
         Draws the button to the buffer
         """
-        buffer.blit(self.rendered_text, (self.x, self.y))
+        buffer.blit(self.rendered_text, self.convert_coords(self.x, self.y))
