@@ -61,7 +61,7 @@ class Text(game_object.GameObject):
         pass
 
     def render(self, buffer: pygame.Surface):
-        buffer.blit(self.rendered_text, (self.x, self.y))
+        buffer.blit(self.rendered_text, self.convert_coords(self.x, self.y))
 
     def set_text(self, text: str):
         """
