@@ -22,6 +22,7 @@ class BaseScreen(abc.ABC):
         self.screen_manager = manager           # type: screen_manager.ScreenManager
         self.dialog_boxes = []                  # type: typing.List[dialog_box.DialogBox]
         self.PIXELS_PER_METER = 100
+        self.fill_background_color = (0, 0, 0)       # type: typing.Union[None, typing.Tuple[int, int, int]]
         self.camera = camera.Camera()
 
     def on_create(self):
@@ -161,7 +162,8 @@ class BaseScreen(abc.ABC):
 
     @abc.abstractmethod
     def render(self, buffer: pygame.Surface):
-        pass
+        if self.fill_background_color is not None:
+            buffer.fill(self.fill_background_color)
 
     def on_key_down(self, unicode, key, mod):
         pass
