@@ -15,9 +15,20 @@ class Camera:
         """
         self.x = x
         self.y = y
+        self.move_callbacks = []        # type: typing.List[callable]
 
     def get_pos(self) -> typing.Tuple[float, float]:
         """
         Returns the coordinates of the camera
         """
         return self.x, self.y
+
+    def move(self, x: float = 0, y: float = 0):
+        self.x += x
+        self.y += y
+
+        self.on_move(x, y)
+
+    def on_move(self, dx, dy):
+        for c in self.move_callbacks:
+            c(-dx, -dy)
