@@ -1,3 +1,6 @@
+"""
+This module contains the image dialog box
+"""
 import abc
 import typing
 import pygame
@@ -6,7 +9,16 @@ import FangEngine.screen_manager.dialog_box as dialog_box
 
 
 class ImageDialogBox(dialog_box.DialogBox, abc.ABC):
+    """
+    The image dialog box does the same thing as a regular dialog box, but it has an image background instead of a color
+    """
     def __init__(self, screen_parent, background_image: pygame.Surface, *args, **kwargs):
+        """
+        :param screen_parent:
+        :param background_image: the pygame surface of the background image
+        :param args:
+        :param kwargs:
+        """
         super().__init__(screen_parent, *args, **kwargs)
         self.fill_background = False
         self.background_image = pygame.transform.scale(background_image, [int(i) for i in self.size])
