@@ -55,6 +55,9 @@ class ObjectScreen(base_screen.BaseScreen):
             if c == child:
                 continue
 
+            if not c.visible:
+                continue
+
             if c.hitbox.is_hitbox_colliding(child.hitbox):
                 child.on_collide(c)
                 c.on_collide(child)
@@ -68,8 +71,11 @@ class ObjectScreen(base_screen.BaseScreen):
             child.update(delta_t)
 
     def render(self, buffer: pygame.Surface):
+        super(ObjectScreen, self).render(buffer)
+
         for child in self.game_objects:
-            child.render(buffer)
+            if child.visible:
+                child.render(buffer)
 
     def on_key_down(self, unicode, key, mod):
         for child in self.game_objects:
